@@ -172,6 +172,7 @@ function normalize (args) {
   if (normalized.substr(-1) === "/") {
     normalized = normalized.substr(0, normalized.length - 1)
   }
+  normalized = path.normalize(normalized)
   log.silly("ls", "normalized", normalized)
 
   return normalized
@@ -202,7 +203,7 @@ function clean (args, cb) {
 
   if (!args) args = []
 
-  var f = path.join(npm.cache, path.normalize(normalize(args)))
+  var f = path.join(npm.cache, normalize(args))
   if (f === npm.cache) {
     fs.readdir(npm.cache, function (er, files) {
       if (er) return cb()
@@ -213,7 +214,10 @@ function clean (args, cb) {
                 })
               , rm, cb )
     })
-  } else rm(path.join(npm.cache, path.normalize(normalize(args))), cb)
+  }
+  else {
+    rm(f, cb)
+  }
 }
 
 // npm cache add <tarball-url>
