@@ -140,16 +140,21 @@ var commandCache = {}
               ]
   , plumbing = [ "build"
                , "unbuild"
-               , "isntall"
                , "xmas"
                , "substack"
                , "visnup"
                ]
-  , fullList = npm.fullList = cmdList.concat(aliasNames).filter(function (c) {
+  , littleGuys = [ "isntall" ]
+  , fullList = cmdList.concat(aliasNames).filter(function (c) {
       return plumbing.indexOf(c) === -1
     })
   , abbrevs = abbrev(fullList)
 
+// we have our reasons
+fullList = npm.fullList = fullList.filter(function (c) {
+  return littleGuys.indexOf(c) === -1
+})
+
 npm.spinner =
   { int: null
   , started: false
