@@ -269,10 +269,10 @@ function shouldUpdate (args, dir, dep, has, req, depth, cb) {
     return doIt("git", "git")
 
   // search for the latest package
-  mapToRegistry(dep, npm.config, function (er, uri) {
+  mapToRegistry(dep, npm.config, function (er, uri, auth) {
     if (er) return cb(er)
 
-    npm.registry.get(uri, null, updateDeps)
+    npm.registry.get(uri, { auth : auth }, updateDeps)
   })
 
   function updateDeps (er, d) {
