@@ -24,10 +24,10 @@ function unbuild_ (silent) { return function (folder, cb_) {
   }
   folder = path.resolve(folder)
   delete build._didBuild[folder]
-  log.verbose(folder.substr(npm.prefix.length + 1), "unbuild")
+  log.verbose("unbuild", folder.substr(npm.prefix.length + 1))
   readJson(path.resolve(folder, "package.json"), function (er, pkg) {
     // if no json, then just trash it, but no scripts or whatever.
-    if (er) return gentlyRm(folder, false, cb)
+    if (er) return gentlyRm(folder, false, npm.prefix, cb)
     readJson.cache.del(folder)
     chain
       ( [ [lifecycle, pkg, "preuninstall", folder, false, true]
@@ -38,7 +38,7 @@ function unbuild_ (silent) { return function (folder, cb_) {
           }
         , [rmStuff, pkg, folder]
         , [lifecycle, pkg, "postuninstall", folder, false, true]
-        , [gentlyRm, folder, undefined] ]
+        , [gentlyRm, folder, false, npm.prefix] ]
       , cb )
   })
 }}
@@ -53,7 +53,8 @@ function rmStuff (pkg, folder, cb) {
 
   readJson.cache.del(path.resolve(folder, "package.json"))
 
-  log.verbose([top, gnm, parent], "unbuild " + pkg._id)
+  log.verbose("unbuild rmStuff", pkg._id, "from", gnm)
+  if (!top) log.verbose("unbuild rmStuff", "in", parent)
   asyncMap([rmBins, rmMans], function (fn, cb) {
     fn(pkg, folder, parent, top, cb)
   }, cb)
@@ -62,15 +63,12 @@ function rmStuff (pkg, folder, cb) {
 function rmBins (pkg, folder, parent, top, cb) {
   if (!pkg.bin) return cb()
   var binRoot = top ? npm.bin : path.resolve(parent, ".bin")
-  log.verbose([binRoot, pkg.bin], "binRoot")
   asyncMap(Object.keys(pkg.bin), function (b, cb) {
     if (process.platform === "win32") {
-      chain([ [gentlyRm, path.resolve(binRoot, b) + ".cmd", undefined]
-            , [gentlyRm, path.resolve(binRoot, b), undefined] ], cb)
+      chain([ [gentlyRm, path.resolve(binRoot, b) + ".cmd", true]
+            , [gentlyRm, path.resolve(binRoot, b), true] ], cb)
     } else {
-      gentlyRm( path.resolve(binRoot, b)
-              , !npm.config.get("force") && folder
-              , cb )
+      gentlyRm(path.resolve(binRoot, b), true, cb)
     }
   }, cb)
 }
@@ -102,9 +100,7 @@ function rmMans (pkg, folder, parent, top, cb) {
                               : pkg.name + "-" + bn)
                               + "." + sxn + gz
                             )
-      gentlyRm( manDest
-              , !npm.config.get("force") && folder
-              , cb )
+      gentlyRm(manDest, true, cb)
     }
   }, cb)
 }
