@@ -3,7 +3,7 @@ exports.cmd = cmd
 exports.makeEnv = makeEnv
 
 var log = require("npmlog")
-  , spawn = require("child_process").spawn
+  , spawn = require("./spawn")
   , npm = require("../npm.js")
   , path = require("path")
   , fs = require("graceful-fs")
@@ -71,11 +71,6 @@ function lifecycle_ (pkg, stage, wd, env, unsafe, failOk, cb) {
     , p = wd.split("node_modules")
     , acc = path.resolve(p.shift())
 
-  // first add the directory containing the `node` executable currently
-  // running, so that any lifecycle script that invoke "node" will execute
-  // this same one.
-  pathArr.unshift(path.dirname(process.execPath))
-
   p.forEach(function (pp) {
     pathArr.unshift(path.join(acc, "node_modules", ".bin"))
     acc = path.join(acc, "node_modules", pp)
@@ -96,24 +91,23 @@ function lifecycle_ (pkg, stage, wd, env, unsafe, failOk, cb) {
     env.npm_lifecycle_script = pkg.scripts[stage]
   }
 
-  if (failOk) {
-    cb = (function (cb_) { return function (er) {
-      if (er) log.warn("continuing anyway", er.message)
-      cb_()
-    }})(cb)
-  }
-
-  if (npm.config.get("force")) {
-    cb = (function (cb_) { return function (er) {
-      if (er) log.info("forced, continuing", er)
-      cb_()
-    }})(cb)
+  function done (er) {
+    if (er) {
+      if (npm.config.get("force")) {
+        log.info("forced, continuing", er)
+        er = null
+      } else if (failOk) {
+        log.warn("continuing anyway", er.message)
+        er = null
+      }
+    }
+    cb(er)
   }
 
   chain
     ( [ packageLifecycle && [runPackageLifecycle, pkg, env, wd, unsafe]
       , [runHookLifecycle, pkg, env, wd, unsafe] ]
-    , cb )
+    , done )
 }
 
 function validWd (d, cb) {
@@ -354,13 +348,9 @@ function makeEnv (data, prefix, env) {
 
 function cmd (stage) {
   function CMD (args, cb) {
-    if (args.length) {
-      chain(args.map(function (p) {
-        return [npm.commands, "run-script", [p, stage]]
-      }), cb)
-    } else npm.commands["run-script"]([stage], cb)
+    npm.commands["run-script"]([stage].concat(args), cb)
   }
-  CMD.usage = "npm "+stage+" <name>"
+  CMD.usage = "npm "+stage+" [-- <args>]"
   var installedShallow = require("./completion/installed-shallow.js")
   CMD.completion = function (opts, cb) {
     installedShallow(opts, function (d) {
