@@ -1,11 +1,11 @@
 module.exports = spawn
 
-var _spawn = require("child_process").spawn,
-     EventEmitter = require("events").EventEmitter
+var _spawn = require("child_process").spawn
+var EventEmitter = require("events").EventEmitter
 
 function spawn (cmd, args, options) {
   var raw = _spawn(cmd, args, options)
-      cooked = new EventEmitter()
+  var cooked = new EventEmitter()
 
   raw.on("error", function (er) {
     er.file = cmd
@@ -19,4 +19,4 @@ function spawn (cmd, args, options) {
   cooked.stderr = raw.stderr
 
   return cooked
-}
\ No newline at end of file
+}
